searchData={"items":[{"type":"module","title":"Membrane.RTP.H265.AP","doc":"Module responsible for parsing Aggregation Packets.\n\nDocumented in [RFC7798](https://tools.ietf.org/html/rfc7798#page-28)\n\n```\n  0                   1                   2                   3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                         RTP Header                            |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |    PayloadHdr (Type=48)     |        NALU 1 Size              |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        NALU 1 HDR           |                                 |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+      NALU 1 Data              |\n  |                  . . .                                        |\n  |                                                               |\n  +               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  | . . .         | NALU 2 Size                   | NALU 2 HDR    |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  | NALU 2 HDR    |                                               |\n  +-+-+-+-+-+-+-+-+             NALU 2 Data                       |\n  |                   . . .                                       |\n  |                               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                               :...OPTIONAL RTP padding        |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n```\n\nA packet width DONL\n```\n0                   1                   2                   3\n0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|                          RTP Header                           |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|     PayloadHdr (Type=48)    |          NALU 1 DONL            |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|         NALU 1 Size         |          NALU 1 HDR             |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|                                                               |\n|                NALU 1 Data  . . .                             |\n|                                                               |\n+     . . .    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+|\n| NALU 2 DOND  |               NALU 2 Size                      |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|         NALU 2 HDR          |                                 |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+         NALU 2 Data           |\n|                                                               |\n|          . . .                +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|                               :...OPTIONAL RTP padding        |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n```","ref":"Membrane.RTP.H265.AP.html"},{"type":"function","title":"Membrane.RTP.H265.AP.aggregation_unit_size/1","doc":"","ref":"Membrane.RTP.H265.AP.html#aggregation_unit_size/1"},{"type":"function","title":"Membrane.RTP.H265.AP.parse/2","doc":"","ref":"Membrane.RTP.H265.AP.html#parse/2"},{"type":"function","title":"Membrane.RTP.H265.AP.serialize/4","doc":"","ref":"Membrane.RTP.H265.AP.html#serialize/4"},{"type":"type","title":"Membrane.RTP.H265.AP.don/0","doc":"","ref":"Membrane.RTP.H265.AP.html#t:don/0"},{"type":"module","title":"Membrane.RTP.H265.Depayloader","doc":"Depayloads H265 RTP payloads into H265 NAL Units.\n\nBased on [RFC 7798](https://tools.ietf.org/html/rfc7798).\n\nSupported types: Single NALU, Fragmentation Unit, Aggegration Packets.","ref":"Membrane.RTP.H265.Depayloader.html"},{"type":"module","title":"Element options - Membrane.RTP.H265.Depayloader","doc":"Passed via struct `t:Membrane.RTP.H265.Depayloader.t/0`\n\n- `sprop_max_don_diff`  \n\n  ```\n  0..32767\n  ```\n  \n  Default value: `0`  \n  Specify the maximum absolute difference between the decoding order number (i.e. AbsDon)\n  values of any two NAL units naluA and naluB, where naluA follows naluB in decoding order\n  and precedes naluB in transmission order.\n  \n  If this value is greater than 0, then two additional fields `DONL` and `DOND` will\n  be included in the RTP payload. A `decoding_order_number` field will be added to the\n  buffer metadata.","ref":"Membrane.RTP.H265.Depayloader.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.H265.Depayloader","doc":"### `:input`\n\nAccepted formats:\n```\n%RTP{payload_format: format} when format in [nil, H265]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%H265{alignment: :nalu, stream_structure: :annexb}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.RTP.H265.Depayloader.html#module-pads"},{"type":"function","title":"Membrane.RTP.H265.Depayloader.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.H265.Depayloader.html#options/0"},{"type":"type","title":"Membrane.RTP.H265.Depayloader.t/0","doc":"Struct containing options for `Membrane.RTP.H265.Depayloader`","ref":"Membrane.RTP.H265.Depayloader.html#t:t/0"},{"type":"module","title":"Membrane.RTP.H265.FU","doc":"Module responsible for parsing H265 Fragmentation Unit.","ref":"Membrane.RTP.H265.FU.html"},{"type":"function","title":"Membrane.RTP.H265.FU.parse/3","doc":"Parses H265 Fragmentation Unit\n\nIf a packet that is being parsed is not considered last then a `{:incomplete, t()}`\ntuple  will be returned.\nIn case of last packet `{:ok, {type, data, don}}` tuple will be returned, where data\nis `NAL Unit` created by concatenating subsequent Fragmentation Units and `don` is the\ndecoding order number of the `NAL unit` in case `donl` field is present in the packet.","ref":"Membrane.RTP.H265.FU.html#parse/3"},{"type":"function","title":"Membrane.RTP.H265.FU.serialize/2","doc":"Serialize H265 unit into list of FU payloads","ref":"Membrane.RTP.H265.FU.html#serialize/2"},{"type":"type","title":"Membrane.RTP.H265.FU.don/0","doc":"","ref":"Membrane.RTP.H265.FU.html#t:don/0"},{"type":"type","title":"Membrane.RTP.H265.FU.t/0","doc":"","ref":"Membrane.RTP.H265.FU.html#t:t/0"},{"type":"module","title":"Membrane.RTP.H265.FU.Header","doc":"Defines a structure representing Fragmentation Unit (FU) header\nwhich is defined in [RFC7798](https://tools.ietf.org/html/rfc7798#page-30)\n\n```\n  +---------------+\n  |0|1|2|3|4|5|6|7|\n  +-+-+-+-+-+-+-+-+\n  |S|E| FuType    |\n  +---------------+\n```","ref":"Membrane.RTP.H265.FU.Header.html"},{"type":"function","title":"Membrane.RTP.H265.FU.Header.add_header/4","doc":"Adds FU header","ref":"Membrane.RTP.H265.FU.Header.html#add_header/4"},{"type":"function","title":"Membrane.RTP.H265.FU.Header.parse/1","doc":"Parses Fragmentation Unit Header\n\nIt will fail if the Start bit and End bit are both set to one in the\nsame Fragmentation Unit Header, because a fragmented NAL unit\nMUST NOT be transmitted in one FU.","ref":"Membrane.RTP.H265.FU.Header.html#parse/1"},{"type":"type","title":"Membrane.RTP.H265.FU.Header.end_flag/0","doc":"MUST be set to true only in the last packet in a sequence.","ref":"Membrane.RTP.H265.FU.Header.html#t:end_flag/0"},{"type":"type","title":"Membrane.RTP.H265.FU.Header.start_flag/0","doc":"MUST be set to true only in the first packet in a sequence.","ref":"Membrane.RTP.H265.FU.Header.html#t:start_flag/0"},{"type":"type","title":"Membrane.RTP.H265.FU.Header.t/0","doc":"","ref":"Membrane.RTP.H265.FU.Header.html#t:t/0"},{"type":"module","title":"Membrane.RTP.H265.NAL.Header","doc":"Defines a structure representing Network Abstraction Layer Unit Header\n\nDefined in [RFC 7798](https://tools.ietf.org/html/rfc7798#section-1.1.4)\n\n```\n  +---------------+---------------+\n  |0|1|2|3|4|5|6|7|0|1|2|3|4|5|6|7|\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |F|   Type    |  LayerId  | TID |\n  +-------------+-----------------+\n```","ref":"Membrane.RTP.H265.NAL.Header.html"},{"type":"function","title":"Membrane.RTP.H265.NAL.Header.add_header/5","doc":"Adds NAL header to payload","ref":"Membrane.RTP.H265.NAL.Header.html#add_header/5"},{"type":"function","title":"Membrane.RTP.H265.NAL.Header.decode_type/1","doc":"Parses type stored in NAL Header","ref":"Membrane.RTP.H265.NAL.Header.html#decode_type/1"},{"type":"function","title":"Membrane.RTP.H265.NAL.Header.encode_type/1","doc":"Encodes given NAL type","ref":"Membrane.RTP.H265.NAL.Header.html#encode_type/1"},{"type":"function","title":"Membrane.RTP.H265.NAL.Header.parse_unit_header/1","doc":"","ref":"Membrane.RTP.H265.NAL.Header.html#parse_unit_header/1"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.nuh_layer_id/0","doc":"Required to be 0 in first version of HEVC, may be used in future extensions.","ref":"Membrane.RTP.H265.NAL.Header.html#t:nuh_layer_id/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.nuh_temporal_id_plus1/0","doc":"Specifies the temporal sub-layer identifier of the NAL unit plus 1.","ref":"Membrane.RTP.H265.NAL.Header.html#t:nuh_temporal_id_plus1/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.supported_types/0","doc":"","ref":"Membrane.RTP.H265.NAL.Header.html#t:supported_types/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.t/0","doc":"","ref":"Membrane.RTP.H265.NAL.Header.html#t:t/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.type/0","doc":"Specifies the type of RBSP data structure contained in the NAL unit.","ref":"Membrane.RTP.H265.NAL.Header.html#t:type/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.types/0","doc":"","ref":"Membrane.RTP.H265.NAL.Header.html#t:types/0"},{"type":"type","title":"Membrane.RTP.H265.NAL.Header.unsupported_types/0","doc":"","ref":"Membrane.RTP.H265.NAL.Header.html#t:unsupported_types/0"},{"type":"module","title":"Membrane.RTP.H265.Payloader","doc":"Payloads H265 NAL units into RTP packets.\n\nBased on [RFC 7798](https://tools.ietf.org/html/rfc7798).","ref":"Membrane.RTP.H265.Payloader.html"},{"type":"module","title":"Element options - Membrane.RTP.H265.Payloader","doc":"Passed via struct `t:Membrane.RTP.H265.Payloader.t/0`\n\n- `max_payload_size`  \n\n  ```\n  non_neg_integer()\n  ```\n  \n  Default value: `1400`  \n  Maximal size of outputted payloads in bytes. Doesn't work in\n  the `single_nalu` mode. The resulting RTP packet will also contain\n  RTP header (12B) and potentially RTP extensions. For most\n  applications, everything should fit in standard MTU size (1500B)\n  after adding L3 and L2 protocols' overhead.\n\n\n- `mode`  \n\n  ```\n  :single_nalu | :non_interleaved\n  ```\n  \n  Default value: `:non_interleaved`  \n  In `:single_nalu` mode, payloader puts exactly one NAL unit\n  into each payload, altering only RTP metadata. `:non_interleaved`\n  mode handles also FU and AP packetization. See\n  [RFC 7798](https://tools.ietf.org/html/rfc7798) for details.","ref":"Membrane.RTP.H265.Payloader.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.H265.Payloader","doc":"### `:input`\n\nAccepted formats:\n```\n%H265{alignment: :nalu, stream_structure: :annexb}\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%RTP{payload_format: H265}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.RTP.H265.Payloader.html#module-pads"},{"type":"function","title":"Membrane.RTP.H265.Payloader.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.H265.Payloader.html#options/0"},{"type":"type","title":"Membrane.RTP.H265.Payloader.t/0","doc":"Struct containing options for `Membrane.RTP.H265.Payloader`","ref":"Membrane.RTP.H265.Payloader.html#t:t/0"},{"type":"extras","title":"Membrane RTP H265 plugin","doc":"# Membrane RTP H265 plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_rtp_h265_plugin.svg)](https://hex.pm/packages/membrane_rtp_h265_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_rtp_h265_plugin/)\n\nRTP payloader and depayloader for H265.","ref":"readme.html"},{"type":"extras","title":"Supported packetization modes - Membrane RTP H265 plugin","doc":"This package does support the following (de)packetization modes:\n  * Single NALu\n  * Fragmentation Unit\n  * Aggregation Packets\n\nIt does not support `PACI` packets.\n\nPlease refer to [RFC 7798](https://tools.ietf.org/html/rfc7798) for details.","ref":"readme.html#supported-packetization-modes"},{"type":"extras","title":"Installation - Membrane RTP H265 plugin","doc":"The package can be installed by adding `membrane_rtp_h265_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_rtp_h265_plugin, \"~> 0.5.3\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2019 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}